<?php

/*
 * @validateInputOutputFields
 * $id - id number of record, zero means add new record
 * $type
 * $methodID - parent of this record
 * $name - uniqe name of this record
 * $dataName - friendly name
 * $updateRRA
 * $typeCode
 * $regexpMatch
 *
 * Function inicialize and validate input or output fields
 */
function validateInputOutputFields($id, $type, $methodID, $name, $dataName,  $updateRRA, $typeCode, $regexpMatch, $allowNulls){
	$data_input_fields = array();
	$sequence = 0;
	
	$id = validateIsNumeric($id,"id", true, "ID must be numeric");
	$type = validate($type,"type",false,"","You must supply a type");	
	$methodID = validate($methodID,"methodID",false,"","You must supply a method ID");	
	$methodID = validateIsNumeric($methodID,"methodID", false, "MethodID must be numeric");	
	$name = validate($name,"name",false,"","You must supply a name");	
	$dataName = validate($dataName,"dataName",false,"","You must supply a data name");
		
	if ($type == 'output') {
		$input_output = "out";
		$updateRRA = (($updateRRA == "on" || $updateRRA == true) ? "on" : "");
		$allowNulls = "";
		$typeCode = "";
		$regexpMatch = "";
		$allowNulls = "";
	}elseif ($type == 'input') {
		$input_output = "in";
		$updateRRA = "";
		$allowNulls = (($allowNulls  == "on" || $allowNulls  == true) ? "on" : "");
		
		$typeCode = validate($typeCode,"typeCode",true,"","You must supply a type code");
		$regexpMatch = validate($regexpMatch,"regexpMatch",true,"","You must supply a regexp match with");
	}else{
		catchException($type,"type","validateInputOutputFields","Invalit type: $type");
  	}

	$data_input_fields["id"] = $id; # Zero means create a new one rather than save over an existing one
	$data_input_fields["hash"] = get_hash_data_input($id, "data_input_field");
	$data_input_fields["data_input_id"] = $methodID; # method ID
	$data_input_fields["name"] = $name; # Field [Output] - Enter a name for this Output field.
	$data_input_fields["data_name"] = $dataName; # Friendly Name - Enter a meaningful name for this data input method.
	$data_input_fields["input_output"] = $input_output;
	$data_input_fields["update_rra"] = $updateRRA; # Update RRD File - Whether data from this output field is to be entered into the rrd file.
	$data_input_fields["sequence"] = $sequence; # number of input parameters
	$data_input_fields["type_code"] = $typeCode; # Special Type Code
	$data_input_fields["regexp_match"] = $regexpMatch; # Regular Expression Match
	$data_input_fields["allow_nulls"] = $allowNulls; # Allow Empty Input

  	return $data_input_fields;
}

/*
 * @validateMethodFields
 * $id - id number of record, zero means add new record
 * $name - uniqe name of method
 * $inputString - input string
 * $inputType - type of intput
 *
 * Function that inicialize and validate method fields
 */
function validateMethodFields($id, $name, $inputString, $inputType) {
	$inputTypes = array('' => '', 2 => 2, 3 => 3, 1 => 1, 4 => 4, 5 => 5, 6 => 6, 'snmp' => 2, 'snmpquery' => 3, 'scriptcommand' => 1, 'scriptquery' => 4, 'scriptserver' => 5, 'scriptqueryserver' => 6);
    #3 - SNMP Query #1 - Script/Command #4 - Script Query #5 - Script - Script Server (PHP) #6 - Script Query - Script Server

    $id = validateIsNumeric($id,"id", true, "ID must be numeric");		
    $name = validate($name,"name", false, "", "You must supply a name");
	$inputString = validate($inputString,"inputString", true, "", "You must supply a input string");
	$inputType = validate($inputTypes[$inputType],"inputType",false,"","You must supply valid input type");

    $data_input = array();
    $data_input["id"] = $id; # Zero means create a new one rather than save over an existing one
    $data_input["hash"] = get_hash_data_input($id);
    $data_input["name"] = $name;
    $data_input["input_string"] = $inputString;
    $data_input["type_id"] = $inputTypes[$inputType];

    return $data_input;
}

/*
 * @validate
 * $field_value - value
 * $is_numeric
 * $regexp_match - regular expression
 * $allow_nulls - allow nulls is true or false
 * $custom_message - error message
 *
 * Validate input values, if field has invalit data then we show error message 
 * and throw error exception, else we return validate value
 */
function validate($field_value, $field_name, $allow_nulls, $regexp_match, $custom_message) {
	/* write current values to the "field_values" array so we can retain them */

	if (($allow_nulls == true) && ($field_value == "")) {
		return $field_value;
	}

	/* php 4.2+ complains about empty regexps */
	if (empty($regexp_match)) { $regexp_match = ".*"; }

	if ((!ereg($regexp_match, $field_value) || (($allow_nulls == false) && ($field_value == "")))) {
        //throw new Exception($custom_message);
        catchException($field_value,$field_name,"validate",$custom_message);
        return;
	}
    return $field_value;
}

  /*
 * @validateIsNumeric
 * $field_value - value
 * $field_name
 * $allow_nulls - allow nulls is true or false
 * $custom_message - error message
 *
 * Validate input values, if field has invalit numeric data then we show error message
 * and throw error exception, else we return validate value
 */
function validateIsNumeric($field_value, $field_name, $allow_nulls, $custom_message) {
	/* write current values to the "field_values" array so we can retain them */

	if($allow_nulls == true){
        if ($field_value == ""){ //numeric empty
        	return $field_value;
        }
    }else{ //($allow_nulls == false)
        if($field_value == ""){ //numeric empty
            #throw exception must not be empty
            catchException($field_value,$field_name,"validateIsNumeric",$custom_message);
            return;
        }
  	}

    if(!is_numeric($field_value)){
        #throw exception  is not numeric
        catchException($field_value,$field_name,"validateIsNumeric",$custom_message);
        return;
    }
  
  	return $field_value;
}

/*
 * @checkAvalibleInputOutputFields
 * $input_string - script path and input and output parmameters
 *
 * Function check for input parameters of method. Function return 
 * parameters or return null
 */
function checkAvalibleInputOutputFields($input_string) {
	/* obtain a list of available fields for this given field type (input/output) */
	//$array_field_names = array();
	global $registered_cacti_names;
	if (preg_match_all("/<([_a-zA-Z0-9]+)>/", $input_string, $matches)) {
		for ($i=0; ($i < count($matches[1])); $i++) {
			if (in_array($matches[1][$i], $registered_cacti_names) == false) {
				$current_field_name = $matches[1][$i];
				$array_field_names[$current_field_name] = $current_field_name;
			}
		}
	}
	
	/* if there are no input fields to choose from, complain */
	if(isset($array_field_names)) {
		// This script appears to have no input values, therefore there is nothing to add.
		return $array_field_names; //there are input param
	}else{
		return;
	}
}

?>